# Videopypeline

![example workflow](https://github.com/eliacarrara/videopypeline/actions/workflows/python-app.yml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/videopypeline/badge/?version=latest)](https://videopypeline.readthedocs.io/en/latest/?badge=latest)

A fancy wrapper for [opencv](https://opencv.org/) inspired by the [keras model API](https://keras.io/api/models/model/).

| Type          | URL                                             |
|---------------|-------------------------------------------------|
| homepage      | https://pypi.org/project/videopypeline/         |
| repository    | https://github.com/eliacarrara/videopypeline    |
| documentation | https://videopypeline.readthedocs.io/en/latest/ |
